@@ -87,7 +87,7 @@ class MSData:
         for spec in spectra:
             # Check if the retention time is within the range
             rt = spec['scanList']['scan'][0]['scan start time'] / 60
-            if rtRange[0] * 60 < rt < rtRange[1] * 60:
+            if rtRange[0] < rt < rtRange[1]:
                 # Check if the scan is MS1 and the scan is not empty
                 if spec['ms level'] == 1 and len(spec['m/z array']) != 0:
                     # Create a ms1Spectrum object
